@@ -45,6 +45,8 @@ extern FILE *tool_stderr;
 
 #include <curl/curl.h> /* external interface */
 
+#include "timeval.h"
+
 /*
  * Platform specific stuff.
  */
@@ -53,8 +55,8 @@ extern FILE *tool_stderr;
 #  define main(x,y) curl_main(x,y)
 #endif
 
-#ifndef OS
-#  define OS "unknown"
+#ifndef CURL_OS
+#  define CURL_OS "unknown"
 #endif
 
 #ifndef UNPRINTABLE_CHAR
@@ -66,10 +68,50 @@ extern FILE *tool_stderr;
 #  include "tool_strdup.h"
 #endif
 
-#if defined(WIN32) && !defined(MSDOS)
-/* set in win32_init() */
-extern LARGE_INTEGER tool_freq;
-extern bool tool_isVistaOrGreater;
+#ifndef tool_nop_stmt
+#define tool_nop_stmt do { } while(0)
 #endif
 
+#ifdef _WIN32
+#  define CURL_STRICMP(p1, p2)  _stricmp(p1, p2)
+#elif defined(HAVE_STRCASECMP)
+#  ifdef HAVE_STRINGS_H
+#    include <strings.h>
+#  endif
+#  define CURL_STRICMP(p1, p2)  strcasecmp(p1, p2)
+#elif defined(HAVE_STRCMPI)
+#  define CURL_STRICMP(p1, p2)  strcmpi(p1, p2)
+#elif defined(HAVE_STRICMP)
+#  define CURL_STRICMP(p1, p2)  stricmp(p1, p2)
+#else
+#  define CURL_STRICMP(p1, p2)  strcmp(p1, p2)
+#endif
+
+#ifdef _WIN32
+/* set in init_terminal() */
+extern bool tool_term_has_bold;
+
+#ifdef UNDER_CE
+#  undef isatty
+#  define isatty(fd) 0  /* fd is void*, expects int */
+#  undef _get_osfhandle
+#  define _get_osfhandle(fd) (fd)
+#  undef _getch
+#  define _getch() 0
+#endif
+
+#ifndef HAVE_FTRUNCATE
+
+int tool_ftruncate64(int fd, curl_off_t where);
+
+#undef  ftruncate
+#define ftruncate(fd,where) tool_ftruncate64(fd,where)
+
+#define HAVE_FTRUNCATE 1
+#define USE_TOOL_FTRUNCATE 1
+
+#endif /* ! HAVE_FTRUNCATE */
+#endif /* _WIN32 */
+
+
 #endif /* HEADER_CURL_TOOL_SETUP_H */
