@@ -27,7 +27,7 @@
 
 #include <curl/multi.h>
 
-int test(char *URL)
+CURLcode test(char *URL)
 {
   CURL *curl;
   CURLcode res = CURLE_OK;
@@ -42,12 +42,12 @@ int test(char *URL)
     if(res)
       goto test_cleanup;
 
-    fprintf(stderr, "****************************** Do it again\n");
+    curl_mfprintf(stderr, "****************************** Do it again\n");
     res = curl_easy_perform(curl);
   }
 
 test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
-  return (int)res;
+  return res;
 }
