@@ -24,16 +24,16 @@
 
 #include "test.h"
 
-#ifdef USE_WEBSOCKETS
+#ifndef CURL_DISABLE_WEBSOCKETS
 
-static CURLcode ping(CURL *curl, const char *send_payload)
+static CURLcode send_ping(CURL *curl, const char *send_payload)
 {
   size_t sent;
   CURLcode result =
     curl_ws_send(curl, send_payload, strlen(send_payload), &sent, 0,
                  CURLWS_PING);
-  fprintf(stderr,
-          "ws: curl_ws_send returned %d, sent %d\n", result, (int)sent);
+  curl_mfprintf(stderr,
+                "ws: curl_ws_send returned %d, sent %d\n", result, (int)sent);
 
   return result;
 }
@@ -47,23 +47,23 @@ static CURLcode recv_pong(CURL *curl, const char *expected_payload)
   if(!result) {
     if(meta->flags & CURLWS_PONG) {
       int same = 0;
-      fprintf(stderr, "ws: got PONG back\n");
+      curl_mfprintf(stderr, "ws: got PONG back\n");
       if(rlen == strlen(expected_payload)) {
         if(!memcmp(expected_payload, buffer, rlen)) {
-          fprintf(stderr, "ws: got the same payload back\n");
+          curl_mfprintf(stderr, "ws: got the same payload back\n");
           same = 1;
         }
       }
       if(!same)
-        fprintf(stderr, "ws: did NOT get the same payload back\n");
+        curl_mfprintf(stderr, "ws: did NOT get the same payload back\n");
     }
     else {
-      fprintf(stderr, "recv_pong: got %d bytes rflags %x\n", (int)rlen,
-              meta->flags);
+      curl_mfprintf(stderr, "recv_pong: got %d bytes rflags %x\n", (int)rlen,
+                    meta->flags);
     }
   }
-  fprintf(stderr, "ws: curl_ws_recv returned %d, received %d\n", result,
-          (int)rlen);
+  curl_mfprintf(stderr, "ws: curl_ws_recv returned %d, received %d\n", result,
+                (int)rlen);
   return result;
 }
 
@@ -76,8 +76,8 @@ static CURLcode recv_any(CURL *curl)
   if(result)
     return result;
 
-  fprintf(stderr, "recv_any: got %u bytes rflags %x\n", (int)rlen,
-          meta->flags);
+  curl_mfprintf(stderr, "recv_any: got %u bytes rflags %x\n", (int)rlen,
+                meta->flags);
   return CURLE_OK;
 }
 
@@ -87,22 +87,22 @@ static void websocket_close(CURL *curl)
   size_t sent;
   CURLcode result =
     curl_ws_send(curl, "", 0, &sent, 0, CURLWS_CLOSE);
-  fprintf(stderr,
-          "ws: curl_ws_send returned %d, sent %u\n", result, (int)sent);
+  curl_mfprintf(stderr,
+                "ws: curl_ws_send returned %d, sent %u\n", result, (int)sent);
 }
 
 static void websocket(CURL *curl)
 {
   int i = 0;
-  fprintf(stderr, "ws: websocket() starts\n");
+  curl_mfprintf(stderr, "ws: websocket() starts\n");
   do {
     recv_any(curl);
-    fprintf(stderr, "Send ping\n");
-    if(ping(curl, "foobar"))
+    curl_mfprintf(stderr, "Send ping\n");
+    if(send_ping(curl, "foobar"))
       return;
-    fprintf(stderr, "Receive pong\n");
+    curl_mfprintf(stderr, "Receive pong\n");
     if(recv_pong(curl, "foobar")) {
-      printf("Connection closed\n");
+      curl_mprintf("Connection closed\n");
       return;
     }
     sleep(2);
@@ -126,7 +126,7 @@ CURLcode test(char *URL)
     curl_easy_setopt(curl, CURLOPT_VERBOSE, 1L);
     curl_easy_setopt(curl, CURLOPT_CONNECT_ONLY, 2L); /* websocket style */
     res = curl_easy_perform(curl);
-    fprintf(stderr, "curl_easy_perform() returned %d\n", res);
+    curl_mfprintf(stderr, "curl_easy_perform() returned %d\n", res);
     if(res == CURLE_OK)
       websocket(curl);
 
