@@ -34,9 +34,7 @@
 #include "warnless.h"
 #include "memdebug.h"
 
-#if !defined(HAVE_POLL_FINE)    && \
-    !defined(USE_WINSOCK)       && \
-    !defined(FD_SETSIZE)
+#if !defined(HAVE_POLL) && !defined(USE_WINSOCK) && !defined(FD_SETSIZE)
 #error "this test requires FD_SETSIZE"
 #endif
 
@@ -50,16 +48,16 @@
 
 #if defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT)
 
-static int *fd = NULL;
+static int *testfd = NULL;
 static struct rlimit num_open;
 static char msgbuff[256];
 
 static void store_errmsg(const char *msg, int err)
 {
   if(!err)
-    msnprintf(msgbuff, sizeof(msgbuff), "%s", msg);
+    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s", msg);
   else
-    msnprintf(msgbuff, sizeof(msgbuff), "%s, errno %d, %s", msg,
+    curl_msnprintf(msgbuff, sizeof(msgbuff), "%s, errno %d, %s", msg,
               err, strerror(err));
 }
 
@@ -68,10 +66,10 @@ static void close_file_descriptors(void)
   for(num_open.rlim_cur = 0;
       num_open.rlim_cur < num_open.rlim_max;
       num_open.rlim_cur++)
-    if(fd[num_open.rlim_cur] > 0)
-      close(fd[num_open.rlim_cur]);
-  free(fd);
-  fd = NULL;
+    if(testfd[num_open.rlim_cur] > 0)
+      close(testfd[num_open.rlim_cur]);
+  free(testfd);
+  testfd = NULL;
 }
 
 static int fopen_works(void)
@@ -87,7 +85,7 @@ static int fopen_works(void)
     fpa[i] = fopen(DEV_NULL, FOPEN_READTEXT);
     if(!fpa[i]) {
       store_errmsg("fopen failed", errno);
-      fprintf(stderr, "%s\n", msgbuff);
+      curl_mfprintf(stderr, "%s\n", msgbuff);
       ret = 0;
       break;
     }
@@ -103,24 +101,24 @@ static void rlim2str(char *buf, size_t len, rlim_t val)
 {
 #ifdef RLIM_INFINITY
   if(val == RLIM_INFINITY) {
-    msnprintf(buf, len, "INFINITY");
+    curl_msnprintf(buf, len, "INFINITY");
     return;
   }
 #endif
 #ifdef HAVE_LONGLONG
   if(sizeof(rlim_t) > sizeof(long))
-    msnprintf(buf, len, "%llu", (unsigned long long)val);
+    curl_msnprintf(buf, len, "%llu", (unsigned long long)val);
   else
 #endif
   {
     if(sizeof(rlim_t) < sizeof(long))
-      msnprintf(buf, len, "%u", (unsigned int)val);
+      curl_msnprintf(buf, len, "%u", (unsigned int)val);
     else
-      msnprintf(buf, len, "%lu", (unsigned long)val);
+      curl_msnprintf(buf, len, "%lu", (unsigned long)val);
   }
 }
 
-static int rlimit(int keep_open)
+static int test_rlimit(int keep_open)
 {
   int *tmpfd;
   rlim_t nitems, i;
@@ -133,17 +131,27 @@ static int rlimit(int keep_open)
 
   if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
     store_errmsg("getrlimit() failed", errno);
-    fprintf(stderr, "%s\n", msgbuff);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
     return -1;
   }
 
   /* show initial open file limits */
 
   rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
-  fprintf(stderr, "initial soft limit: %s\n", strbuff);
+  curl_mfprintf(stderr, "initial soft limit: %s\n", strbuff);
 
   rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
-  fprintf(stderr, "initial hard limit: %s\n", strbuff);
+  curl_mfprintf(stderr, "initial hard limit: %s\n", strbuff);
+
+  /* If the OS allows a HUGE number of open files, we do not run.
+   * Modern debian sid reports a limit of 134217724 and this tests
+   * takes minutes. */
+#define LIMIT_CAP     (256*1024)
+  if(rl.rlim_cur > LIMIT_CAP) {
+    curl_mfprintf(stderr, "soft limit above %ld, not running\n",
+                  (long)LIMIT_CAP);
+    return -2;
+  }
 
   /*
    * if soft limit and hard limit are different we ask the
@@ -159,23 +167,23 @@ static int rlimit(int keep_open)
 #ifdef OPEN_MAX
     if((rl.rlim_cur > 0) &&
        (rl.rlim_cur < OPEN_MAX)) {
-      fprintf(stderr, "raising soft limit up to OPEN_MAX\n");
+      curl_mfprintf(stderr, "raising soft limit up to OPEN_MAX\n");
       rl.rlim_cur = OPEN_MAX;
       if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
         /* on failure don't abort just issue a warning */
         store_errmsg("setrlimit() failed", errno);
-        fprintf(stderr, "%s\n", msgbuff);
+        curl_mfprintf(stderr, "%s\n", msgbuff);
         msgbuff[0] = '\0';
       }
     }
 #endif
 
-    fprintf(stderr, "raising soft limit up to hard limit\n");
+    curl_mfprintf(stderr, "raising soft limit up to hard limit\n");
     rl.rlim_cur = rl.rlim_max;
     if(setrlimit(RLIMIT_NOFILE, &rl) != 0) {
       /* on failure don't abort just issue a warning */
       store_errmsg("setrlimit() failed", errno);
-      fprintf(stderr, "%s\n", msgbuff);
+      curl_mfprintf(stderr, "%s\n", msgbuff);
       msgbuff[0] = '\0';
     }
 
@@ -183,17 +191,17 @@ static int rlimit(int keep_open)
 
     if(getrlimit(RLIMIT_NOFILE, &rl) != 0) {
       store_errmsg("getrlimit() failed", errno);
-      fprintf(stderr, "%s\n", msgbuff);
+      curl_mfprintf(stderr, "%s\n", msgbuff);
       return -3;
     }
 
     /* show current open file limits */
 
     rlim2str(strbuff, sizeof(strbuff), rl.rlim_cur);
-    fprintf(stderr, "current soft limit: %s\n", strbuff);
+    curl_mfprintf(stderr, "current soft limit: %s\n", strbuff);
 
     rlim2str(strbuff, sizeof(strbuff), rl.rlim_max);
-    fprintf(stderr, "current hard limit: %s\n", strbuff);
+    curl_mfprintf(stderr, "current hard limit: %s\n", strbuff);
 
   } /* (rl.rlim_cur != rl.rlim_max) */
 
@@ -212,7 +220,7 @@ static int rlimit(int keep_open)
    * avoid a low memory condition once the file descriptors are
    * open. System conditions that could make the test fail should
    * be addressed in the precheck phase. This chunk of memory shall
-   * be always free()ed before exiting the rlimit() function so
+   * be always free()ed before exiting the test_rlimit() function so
    * that it becomes available to the test.
    */
 
@@ -223,22 +231,22 @@ static int rlimit(int keep_open)
   do {
     num_open.rlim_max = sizeof(*memchunk) * nitems;
     rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
-    fprintf(stderr, "allocating memchunk %s byte array\n", strbuff);
+    curl_mfprintf(stderr, "allocating memchunk %s byte array\n", strbuff);
     memchunk = malloc(sizeof(*memchunk) * (size_t)nitems);
     if(!memchunk) {
-      fprintf(stderr, "memchunk, malloc() failed\n");
+      curl_mfprintf(stderr, "memchunk, malloc() failed\n");
       nitems /= 2;
     }
   } while(nitems && !memchunk);
   if(!memchunk) {
     store_errmsg("memchunk, malloc() failed", errno);
-    fprintf(stderr, "%s\n", msgbuff);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
     return -4;
   }
 
   /* initialize it to fight lazy allocation */
 
-  fprintf(stderr, "initializing memchunk array\n");
+  curl_mfprintf(stderr, "initializing memchunk array\n");
 
   for(i = 0; i < nitems; i++)
     memchunk[i] = -1;
@@ -264,12 +272,13 @@ static int rlimit(int keep_open)
 
   /* verify that we won't overflow size_t in malloc() */
 
-  if((size_t)(num_open.rlim_max) > ((size_t)-1) / sizeof(*fd)) {
+  if((size_t)(num_open.rlim_max) > ((size_t)-1) / sizeof(*testfd)) {
     rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
-    msnprintf(strbuff, sizeof(strbuff), "unable to allocate an array for %s "
-              "file descriptors, would overflow size_t", strbuff1);
+    curl_msnprintf(strbuff, sizeof(strbuff),
+                   "unable to allocate an array for %s "
+                   "file descriptors, would overflow size_t", strbuff1);
     store_errmsg(strbuff, 0);
-    fprintf(stderr, "%s\n", msgbuff);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
     free(memchunk);
     return -5;
   }
@@ -278,42 +287,43 @@ static int rlimit(int keep_open)
 
   do {
     rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
-    fprintf(stderr, "allocating array for %s file descriptors\n", strbuff);
+    curl_mfprintf(stderr, "allocating array for %s file descriptors\n",
+                  strbuff);
 
-    fd = malloc(sizeof(*fd) * (size_t)(num_open.rlim_max));
-    if(!fd) {
-      fprintf(stderr, "fd, malloc() failed\n");
+    testfd = malloc(sizeof(*testfd) * (size_t)(num_open.rlim_max));
+    if(!testfd) {
+      curl_mfprintf(stderr, "testfd, malloc() failed\n");
       num_open.rlim_max /= 2;
     }
-  } while(num_open.rlim_max && !fd);
-  if(!fd) {
-    store_errmsg("fd, malloc() failed", errno);
-    fprintf(stderr, "%s\n", msgbuff);
+  } while(num_open.rlim_max && !testfd);
+  if(!testfd) {
+    store_errmsg("testfd, malloc() failed", errno);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
     free(memchunk);
     return -6;
   }
 
   /* initialize it to fight lazy allocation */
 
-  fprintf(stderr, "initializing fd array\n");
+  curl_mfprintf(stderr, "initializing testfd array\n");
 
   for(num_open.rlim_cur = 0;
       num_open.rlim_cur < num_open.rlim_max;
       num_open.rlim_cur++)
-    fd[num_open.rlim_cur] = -1;
+    testfd[num_open.rlim_cur] = -1;
 
   rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
-  fprintf(stderr, "trying to open %s file descriptors\n", strbuff);
+  curl_mfprintf(stderr, "trying to open %s file descriptors\n", strbuff);
 
   /* open a dummy descriptor */
 
-  fd[0] = open(DEV_NULL, O_RDONLY);
-  if(fd[0] < 0) {
-    msnprintf(strbuff, sizeof(strbuff), "opening of %s failed", DEV_NULL);
+  testfd[0] = open(DEV_NULL, O_RDONLY);
+  if(testfd[0] < 0) {
+    curl_msnprintf(strbuff, sizeof(strbuff), "opening of %s failed", DEV_NULL);
     store_errmsg(strbuff, errno);
-    fprintf(stderr, "%s\n", msgbuff);
-    free(fd);
-    fd = NULL;
+    curl_mfprintf(stderr, "%s\n", msgbuff);
+    free(testfd);
+    testfd = NULL;
     free(memchunk);
     return -7;
   }
@@ -324,44 +334,46 @@ static int rlimit(int keep_open)
       num_open.rlim_cur < num_open.rlim_max;
       num_open.rlim_cur++) {
 
-    fd[num_open.rlim_cur] = dup(fd[0]);
+    testfd[num_open.rlim_cur] = dup(testfd[0]);
 
-    if(fd[num_open.rlim_cur] < 0) {
+    if(testfd[num_open.rlim_cur] < 0) {
 
-      fd[num_open.rlim_cur] = -1;
+      testfd[num_open.rlim_cur] = -1;
 
       rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
-      msnprintf(strbuff, sizeof(strbuff), "dup() attempt %s failed", strbuff1);
-      fprintf(stderr, "%s\n", strbuff);
+      curl_msnprintf(strbuff, sizeof(strbuff), "dup() attempt %s failed",
+                     strbuff1);
+      curl_mfprintf(stderr, "%s\n", strbuff);
 
       rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
-      msnprintf(strbuff, sizeof(strbuff), "fds system limit seems close to %s",
-                strbuff1);
-      fprintf(stderr, "%s\n", strbuff);
+      curl_msnprintf(strbuff, sizeof(strbuff),
+                     "fds system limit seems close to %s", strbuff1);
+      curl_mfprintf(stderr, "%s\n", strbuff);
 
       num_open.rlim_max = num_open.rlim_cur - SAFETY_MARGIN;
 
       num_open.rlim_cur -= num_open.rlim_max;
       rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_cur);
-      msnprintf(strbuff, sizeof(strbuff), "closing %s file descriptors",
-                strbuff1);
-      fprintf(stderr, "%s\n", strbuff);
+      curl_msnprintf(strbuff, sizeof(strbuff), "closing %s file descriptors",
+                     strbuff1);
+      curl_mfprintf(stderr, "%s\n", strbuff);
 
       for(num_open.rlim_cur = num_open.rlim_max;
-          fd[num_open.rlim_cur] >= 0;
+          testfd[num_open.rlim_cur] >= 0;
           num_open.rlim_cur++) {
-        close(fd[num_open.rlim_cur]);
-        fd[num_open.rlim_cur] = -1;
+        close(testfd[num_open.rlim_cur]);
+        testfd[num_open.rlim_cur] = -1;
       }
 
       rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
-      fprintf(stderr, "shrinking array for %s file descriptors\n", strbuff);
+      curl_mfprintf(stderr, "shrinking array for %s file descriptors\n",
+                    strbuff);
 
       /* we don't care if we can't shrink it */
 
-      tmpfd = realloc(fd, sizeof(*fd) * (size_t)(num_open.rlim_max));
+      tmpfd = realloc(testfd, sizeof(*testfd) * (size_t)(num_open.rlim_max));
       if(tmpfd) {
-        fd = tmpfd;
+        testfd = tmpfd;
         tmpfd = NULL;
       }
 
@@ -370,9 +382,9 @@ static int rlimit(int keep_open)
   }
 
   rlim2str(strbuff, sizeof(strbuff), num_open.rlim_max);
-  fprintf(stderr, "%s file descriptors open\n", strbuff);
+  curl_mfprintf(stderr, "%s file descriptors open\n", strbuff);
 
-#if !defined(HAVE_POLL_FINE) && !defined(USE_WINSOCK)
+#if !defined(HAVE_POLL) && !defined(USE_WINSOCK)
 
   /*
    * when using select() instead of poll() we cannot test
@@ -387,10 +399,10 @@ static int rlimit(int keep_open)
 
   num_open.rlim_cur = FD_SETSIZE - SAFETY_MARGIN;
   if(num_open.rlim_max > num_open.rlim_cur) {
-    msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
+    curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
               FD_SETSIZE);
     store_errmsg(strbuff, 0);
-    fprintf(stderr, "%s\n", msgbuff);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
     close_file_descriptors();
     free(memchunk);
     return -8;
@@ -400,19 +412,19 @@ static int rlimit(int keep_open)
   for(rl.rlim_cur = 0;
       rl.rlim_cur < num_open.rlim_max;
       rl.rlim_cur++) {
-    if((fd[rl.rlim_cur] > 0) &&
-       ((unsigned int)fd[rl.rlim_cur] > num_open.rlim_cur)) {
-      msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
+    if((testfd[rl.rlim_cur] > 0) &&
+       ((unsigned int)testfd[rl.rlim_cur] > num_open.rlim_cur)) {
+      curl_msnprintf(strbuff, sizeof(strbuff), "select limit is FD_SETSIZE %d",
                 FD_SETSIZE);
       store_errmsg(strbuff, 0);
-      fprintf(stderr, "%s\n", msgbuff);
+      curl_mfprintf(stderr, "%s\n", msgbuff);
       close_file_descriptors();
       free(memchunk);
       return -9;
     }
   }
 
-#endif /* using a FD_SETSIZE bound select() */
+#endif /* using an FD_SETSIZE bound select() */
 
   /*
    * Old or 'backwards compatible' implementations of stdio do not allow
@@ -425,10 +437,11 @@ static int rlimit(int keep_open)
 
   if(!fopen_works()) {
     rlim2str(strbuff1, sizeof(strbuff1), num_open.rlim_max);
-    msnprintf(strbuff, sizeof(strbuff), "fopen fails with %s fds open",
-              strbuff1);
-    fprintf(stderr, "%s\n", msgbuff);
-    msnprintf(strbuff, sizeof(strbuff), "fopen fails with lots of fds open");
+    curl_msnprintf(strbuff, sizeof(strbuff), "fopen fails with %s fds open",
+                   strbuff1);
+    curl_mfprintf(stderr, "%s\n", msgbuff);
+    curl_msnprintf(strbuff, sizeof(strbuff),
+                   "fopen fails with lots of fds open");
     store_errmsg(strbuff, 0);
     close_file_descriptors();
     free(memchunk);
@@ -449,21 +462,21 @@ static int rlimit(int keep_open)
   return 0;
 }
 
-int test(char *URL)
+CURLcode test(char *URL)
 {
   CURLcode res;
   CURL *curl;
 
   if(!strcmp(URL, "check")) {
     /* used by the test script to ask if we can run this test or not */
-    if(rlimit(FALSE)) {
-      fprintf(stdout, "rlimit problem: %s\n", msgbuff);
-      return 1;
+    if(test_rlimit(FALSE)) {
+      curl_mfprintf(stdout, "test_rlimit problem: %s\n", msgbuff);
+      return TEST_ERR_FAILURE;
     }
-    return 0; /* sure, run this! */
+    return CURLE_OK; /* sure, run this! */
   }
 
-  if(rlimit(TRUE)) {
+  if(test_rlimit(TRUE)) {
     /* failure */
     return TEST_ERR_MAJOR_BAD;
   }
@@ -472,14 +485,14 @@ int test(char *URL)
      and close them all once the test is over */
 
   if(curl_global_init(CURL_GLOBAL_ALL) != CURLE_OK) {
-    fprintf(stderr, "curl_global_init() failed\n");
+    curl_mfprintf(stderr, "curl_global_init() failed\n");
     close_file_descriptors();
     return TEST_ERR_MAJOR_BAD;
   }
 
   curl = curl_easy_init();
   if(!curl) {
-    fprintf(stderr, "curl_easy_init() failed\n");
+    curl_mfprintf(stderr, "curl_easy_init() failed\n");
     close_file_descriptors();
     curl_global_cleanup();
     return TEST_ERR_MAJOR_BAD;
@@ -496,16 +509,16 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return (int)res;
+  return res;
 }
 
 #else /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
 
-int test(char *URL)
+CURLcode test(char *URL)
 {
   (void)URL;
-  printf("system lacks necessary system function(s)");
-  return 1; /* skip test */
+  curl_mprintf("system lacks necessary system function(s)");
+  return TEST_ERR_MAJOR_BAD; /* skip test */
 }
 
 #endif /* defined(HAVE_GETRLIMIT) && defined(HAVE_SETRLIMIT) */
