@@ -30,20 +30,18 @@
 
 #include "stub_gssapi.h"
 
-/* !checksrc! disable SNPRINTF all */
-
 #define MAX_CREDS_LENGTH 250
 #define APPROX_TOKEN_LEN 250
 
 enum min_err_code {
-    GSS_OK = 0,
-    GSS_NO_MEMORY,
-    GSS_INVALID_ARGS,
-    GSS_INVALID_CREDS,
-    GSS_INVALID_CTX,
-    GSS_SERVER_ERR,
-    GSS_NO_MECH,
-    GSS_LAST
+  GSS_OK = 0,
+  GSS_NO_MEMORY,
+  GSS_INVALID_ARGS,
+  GSS_INVALID_CREDS,
+  GSS_INVALID_CTX,
+  GSS_SERVER_ERR,
+  GSS_NO_MECH,
+  GSS_LAST
 };
 
 static const char *min_err_table[] = {
@@ -91,8 +89,8 @@ OM_uint32 gss_init_sec_context(OM_uint32 *min,
             OM_uint32 *time_rec)
 {
   /* The token will be encoded in base64 */
-  int length = APPROX_TOKEN_LEN * 3 / 4;
-  int used = 0;
+  size_t length = APPROX_TOKEN_LEN * 3 / 4;
+  size_t used = 0;
   char *token = NULL;
   const char *creds = NULL;
   gss_ctx_id_t ctx = NULL;
@@ -183,7 +181,7 @@ OM_uint32 gss_init_sec_context(OM_uint32 *min,
       return GSS_S_FAILURE;
     }
 
-    ctx = (gss_ctx_id_t) calloc(sizeof(*ctx), 1);
+    ctx = (gss_ctx_id_t) calloc(1, sizeof(*ctx));
     if(!ctx) {
       *min = GSS_NO_MEMORY;
       return GSS_S_FAILURE;
@@ -219,8 +217,8 @@ OM_uint32 gss_init_sec_context(OM_uint32 *min,
   /* Token format: creds:target:type:padding */
   /* Note: this is using the *real* snprintf() and not the curl provided
      one */
-  used = snprintf(token, length, "%s:%s:%d:", creds,
-                  (char *) target_name, ctx->sent);
+  used = (size_t) snprintf(token, length, "%s:%s:%d:", creds,
+                           (const char *)target_name, ctx->sent);
 
   if(used >= length) {
     free(token);
@@ -229,7 +227,7 @@ OM_uint32 gss_init_sec_context(OM_uint32 *min,
     return GSS_S_FAILURE;
   }
 
-  /* Overwrite null terminator */
+  /* Overwrite null-terminator */
   memset(token + used, 'A', length - used);
 
   *context_handle = ctx;
