@@ -5,7 +5,7 @@
  *                            | (__| |_| |  _ <| |___
  *                             \___|\___/|_| \_\_____|
  *
- * Copyright (C) 1998 - 2021, Daniel Stenberg, <daniel@haxx.se>, et al.
+ * Copyright (C) Daniel Stenberg, <daniel@haxx.se>, et al.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution. The terms
@@ -18,6 +18,8 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
+ * SPDX-License-Identifier: curl
+ *
  ***************************************************************************/
 #include "curlcheck.h"
 
@@ -31,28 +33,27 @@
 #  include <arpa/inet.h>
 #endif
 
-#define ENABLE_CURLX_PRINTF
-#include "curlx.h"
+#include <curlx.h>
 
 #include "hash.h"
 #include "hostip.h"
 
 #include "memdebug.h" /* LAST include file */
 
-static struct Curl_easy *data;
-static struct Curl_hash hp;
+static struct Curl_easy *testdata;
+static struct Curl_dnscache hp;
 static char *data_key;
 static struct Curl_dns_entry *data_node;
 
 static CURLcode unit_setup(void)
 {
-  data = curl_easy_init();
-  if(!data) {
+  testdata = curl_easy_init();
+  if(!testdata) {
     curl_global_cleanup();
     return CURLE_OUT_OF_MEMORY;
   }
 
-  Curl_init_dnscache(&hp);
+  Curl_dnscache_init(&hp, 7);
   return CURLE_OK;
 }
 
@@ -63,9 +64,9 @@ static void unit_stop(void)
     free(data_node);
   }
   free(data_key);
-  Curl_hash_destroy(&hp);
+  Curl_dnscache_destroy(&hp);
 
-  curl_easy_cleanup(data);
+  curl_easy_cleanup(testdata);
   curl_global_cleanup();
 }
 
@@ -73,7 +74,7 @@ static struct Curl_addrinfo *fake_ai(void)
 {
   static struct Curl_addrinfo *ai;
   static const char dummy[]="dummy";
-  size_t namelen = sizeof(dummy); /* including the zero terminator */
+  size_t namelen = sizeof(dummy); /* including the null-terminator */
 
   ai = calloc(1, sizeof(struct Curl_addrinfo) + sizeof(struct sockaddr_in) +
               namelen);
@@ -93,7 +94,7 @@ static struct Curl_addrinfo *fake_ai(void)
 
 static CURLcode create_node(void)
 {
-  data_key = aprintf("%s:%d", "dummy", 0);
+  data_key = curl_maprintf("%s:%d", "dummy", 0);
   if(!data_key)
     return CURLE_OUT_OF_MEMORY;
 
@@ -120,8 +121,8 @@ UNITTEST_START
     abort_unless(rc == CURLE_OK, "data node creation failed");
     key_len = strlen(data_key);
 
-    data_node->inuse = 1; /* hash will hold the reference */
-    nodep = Curl_hash_add(&hp, data_key, key_len + 1, data_node);
+    data_node->refcount = 1; /* hash will hold the reference */
+    nodep = Curl_hash_add(&hp.entries, data_key, key_len + 1, data_node);
     abort_unless(nodep, "insertion into hash failed");
     /* Freeing will now be done by Curl_hash_destroy */
     data_node = NULL;
